@@ -49,7 +49,7 @@ class provider():
 	def sendSMS(self, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
 		return False, "SMS sending not implemented"
 
-# o2online.de 2.3
+# o2online.de 2.4
 # o2online (DE) Provider written by Bjoern Olausson <maemo@olausson.de>
 class provider_o2online_de(provider):
 	def getName(self):
@@ -291,10 +291,10 @@ class provider_o2online_de(provider):
 			#------------------------------------
 			UpdatePbar(self, MainWindow, app, "5", "Step 5: Open EmailCenter")
 			try:
-				br.find_link(text='E-Mails bearbeiten')
+				br.find_link(text='Mail[IMG]E-Mail')
 			except mechanize.LinkNotFoundError:
-				return error(self, MainWindow, e, 'Step 5: Link "E-Mails bearbeiten" nicht gefunden')
-			req = br.click_link(text='E-Mails bearbeiten')
+				return error(self, MainWindow, e, 'Step 5: Link "E-Mail" nicht gefunden')
+			req = br.click_link(text='Mail[IMG]E-Mail')
 			try:
 				br.open(req)
 				response = br.response().read()
